@@ -4,7 +4,7 @@
 -- Module      :  Graphics.Rendering.OpenGL.GL.BufferMode
 -- Copyright   :  (c) Sven Panne 2002-2009
 -- License     :  BSD-style (see the file libraries/OpenGL/LICENSE)
--- 
+--
 -- Maintainer  :  sven.panne@aedion.de
 -- Stability   :  stable
 -- Portability :  portable
@@ -14,10 +14,12 @@
 --------------------------------------------------------------------------------
 
 module Graphics.Rendering.OpenGL.GL.BufferMode (
-   BufferMode(..), marshalBufferMode, unmarshalBufferMode
+   BufferMode(..), marshalBufferMode, unmarshalBufferMode, unmarshalBufferModeSafe,
+   maxColorAttachments,
 ) where
 
-import Graphics.Rendering.OpenGL.GL.BasicTypes ( GLenum, GLsizei )
+import Graphics.Rendering.OpenGL.Raw.Core31
+import Graphics.Rendering.OpenGL.Raw.ARB.Compatibility ( gl_AUX0 )
 
 --------------------------------------------------------------------------------
 
@@ -59,35 +61,66 @@ data BufferMode =
      -- front left color buffer is selected.
    | AuxBuffer GLsizei
      -- ^ Only the given auxiliary color buffer no. /i/ is selected.
+   | FBOColorAttachment GLsizei
+     -- ^ Only the given color attachment of the bound framebufferobject is selected for reading
+     -- or writing.
    deriving ( Eq, Ord, Show )
 
 marshalBufferMode :: BufferMode -> Maybe GLenum
 marshalBufferMode x = case x of
-   NoBuffers -> Just 0x0
-   FrontLeftBuffer -> Just 0x400
-   FrontRightBuffer -> Just 0x401
-   BackLeftBuffer -> Just 0x402
-   BackRightBuffer -> Just 0x403
-   FrontBuffers -> Just 0x404
-   BackBuffers -> Just 0x405
-   LeftBuffers -> Just 0x406
-   RightBuffers -> Just 0x407
-   FrontAndBackBuffers -> Just 0x408
+   NoBuffers -> Just gl_NONE
+   FrontLeftBuffer -> Just gl_FRONT_LEFT
+   FrontRightBuffer -> Just gl_FRONT_RIGHT
+   BackLeftBuffer -> Just gl_BACK_LEFT
+   BackRightBuffer -> Just gl_BACK_RIGHT
+   FrontBuffers -> Just gl_FRONT
+   BackBuffers -> Just gl_BACK
+   LeftBuffers -> Just gl_LEFT
+   RightBuffers -> Just gl_RIGHT
+   FrontAndBackBuffers -> Just gl_FRONT_AND_BACK
    AuxBuffer i
-      | i <= 246  -> Just (0x409 + fromIntegral i)
+      | fromIntegral i <= maxAuxBuffer -> Just (gl_AUX0 + fromIntegral i)
+      | otherwise -> Nothing
+   FBOColorAttachment i
+      | fromIntegral i <= maxColorAttachments -> Just (gl_COLOR_ATTACHMENT0 + fromIntegral i)
       | otherwise -> Nothing
 
 unmarshalBufferMode :: GLenum -> BufferMode
-unmarshalBufferMode x
-   | x == 0x0 = NoBuffers
-   | x == 0x400 = FrontLeftBuffer
-   | x == 0x401 = FrontRightBuffer
-   | x == 0x402 = BackLeftBuffer
-   | x == 0x403 = BackRightBuffer
-   | x == 0x404 = FrontBuffers
-   | x == 0x405 = BackBuffers
-   | x == 0x406 = LeftBuffers
-   | x == 0x407 = RightBuffers
-   | x == 0x408 = FrontAndBackBuffers
-   | 0x409 <= x && x <= 0x4ff = AuxBuffer (fromIntegral x - 0x409)
-   | otherwise = error ("unmarshalBufferMode: illegal value " ++ show x)
+unmarshalBufferMode x = maybe
+   (error ("unmarshalBufferMode: illegal value " ++ show x)) id $ unmarshalBufferModeSafe x
+--unmarshalBufferMode x
+--   | x == gl_NONE = NoBuffers
+--   | x == gl_FRONT_LEFT = FrontLeftBuffer
+--   | x == gl_FRONT_RIGHT = FrontRightBuffer
+--   | x == gl_BACK_LEFT = BackLeftBuffer
+--   | x == gl_BACK_RIGHT = BackRightBuffer
+--   | x == gl_FRONT = FrontBuffers
+--   | x == gl_BACK = BackBuffers
+--   | x == gl_LEFT = LeftBuffers
+--   | x == gl_RIGHT = RightBuffers
+--   | x == gl_FRONT_AND_BACK = FrontAndBackBuffers
+--   | gl_AUX0 <= x && x <= gl_AUX0 + maxAuxBuffer = AuxBuffer (fromIntegral (x - gl_AUX0))
+--   | otherwise = error ("unmarshalBufferMode: illegal value " ++ show x)
+
+unmarshalBufferModeSafe :: GLenum -> Maybe BufferMode
+unmarshalBufferModeSafe x
+   | x == gl_NONE = Just NoBuffers
+   | x == gl_FRONT_LEFT = Just FrontLeftBuffer
+   | x == gl_FRONT_RIGHT = Just FrontRightBuffer
+   | x == gl_BACK_LEFT = Just BackLeftBuffer
+   | x == gl_BACK_RIGHT = Just BackRightBuffer
+   | x == gl_FRONT = Just FrontBuffers
+   | x == gl_BACK = Just BackBuffers
+   | x == gl_LEFT = Just LeftBuffers
+   | x == gl_RIGHT = Just RightBuffers
+   | x == gl_FRONT_AND_BACK = Just FrontAndBackBuffers
+   | gl_AUX0 <= x && x <= gl_AUX0 + maxAuxBuffer = Just . AuxBuffer . fromIntegral $ x - gl_AUX0
+   | gl_COLOR_ATTACHMENT0 <= x && x <= gl_COLOR_ATTACHMENT0 + maxColorAttachments
+      = Just . FBOColorAttachment . fromIntegral $ x - gl_COLOR_ATTACHMENT0
+   | otherwise = Nothing
+
+maxAuxBuffer :: GLenum
+maxAuxBuffer = 246
+
+maxColorAttachments :: GLenum
+maxColorAttachments = 16
