@@ -1,10 +1,11 @@
+{-# LANGUAGE CPP #-}
 -- #hide
 --------------------------------------------------------------------------------
 -- |
 -- Module      :  Graphics.Rendering.OpenGL.GL.Exception
 -- Copyright   :  (c) Sven Panne 2002-2009
 -- License     :  BSD-style (see the file libraries/OpenGL/LICENSE)
--- 
+--
 -- Maintainer  :  sven.panne@aedion.de
 -- Stability   :  stable
 -- Portability :  portable
@@ -40,9 +41,9 @@ import Control.Exception ( bracket, bracket_, finally )
 {-# INLINE unsafeBracket_ #-}
 unsafeBracket_ :: IO a -> IO b -> IO c -> IO c
 unsafeBracket_ before after thing = do
-   before
+   _ <- before
    r <- thing
-   after
+   _ <- after
    return r
 
 {-# INLINE finallyRet #-}
