@@ -17,23 +17,15 @@ module Graphics.Rendering.OpenGL.GL.PixelData (
    PixelData(..), withPixelData
 ) where
 
-import Foreign.Ptr ( Ptr )
-import Graphics.Rendering.OpenGL.GL.BasicTypes ( GLenum )
-import Graphics.Rendering.OpenGL.GL.DataType ( DataType, marshalDataType )
-import Graphics.Rendering.OpenGL.GL.PixelFormat (
-   PixelFormat, marshalPixelFormat )
+import Foreign.Ptr
+import Graphics.Rendering.OpenGL.GL.DataType
+import Graphics.Rendering.OpenGL.GL.PixelFormat
+import Graphics.Rendering.OpenGL.Raw.Core31
 
 --------------------------------------------------------------------------------
 
 data PixelData a = PixelData PixelFormat DataType (Ptr a)
-#ifdef __HADDOCK__
--- Help Haddock a bit, because it doesn't do any instance inference.
-instance Eq (PixelData a)
-instance Ord (PixelData a)
-instance Show (PixelData a)
-#else
    deriving ( Eq, Ord, Show )
-#endif
 
 withPixelData :: PixelData a -> (GLenum -> GLenum -> Ptr a -> b) -> b
 withPixelData (PixelData pixelFormat dataType ptr) f =
