@@ -17,8 +17,8 @@ module Graphics.Rendering.OpenGL.GL.PixelRectangles.Reset (
    Reset(..), marshalReset
 ) where
 
-import Graphics.Rendering.OpenGL.GL.BasicTypes ( GLboolean )
-import Graphics.Rendering.OpenGL.GL.GLboolean ( marshalGLboolean )
+import Graphics.Rendering.OpenGL.GL.GLboolean
+import Graphics.Rendering.OpenGL.Raw.Core31
 
 --------------------------------------------------------------------------------
 
