@@ -17,9 +17,8 @@ module Graphics.Rendering.OpenGL.GL.PixelRectangles.Sink (
    Sink(..), marshalSink, unmarshalSink
 ) where
 
-import Graphics.Rendering.OpenGL.GL.BasicTypes ( GLboolean, GLint )
-import Graphics.Rendering.OpenGL.GL.GLboolean (
-   marshalGLboolean, unmarshalGLboolean )
+import Graphics.Rendering.OpenGL.GL.GLboolean
+import Graphics.Rendering.OpenGL.Raw.Core31
 
 --------------------------------------------------------------------------------
 
