@@ -17,14 +17,10 @@ module Graphics.Rendering.OpenGL.GL.PointParameter (
    PointParameter(..), pointParameterf, pointParameterfv
 ) where
 
-import Foreign.Ptr ( Ptr )
-import Graphics.Rendering.OpenGL.GL.BasicTypes ( GLenum, GLfloat )
-import Graphics.Rendering.OpenGL.GL.Extensions (
-   FunPtr, unsafePerformIO, Invoker, getProcAddress )
-
---------------------------------------------------------------------------------
-
-#include "HsOpenGLExt.h"
+import Foreign.Ptr
+import Graphics.Rendering.OpenGL.Raw.ARB.Compatibility (
+ gl_POINT_DISTANCE_ATTENUATION, gl_POINT_SIZE_MAX, gl_POINT_SIZE_MIN )
+import Graphics.Rendering.OpenGL.Raw.Core31
 
 --------------------------------------------------------------------------------
 
@@ -36,19 +32,15 @@ data PointParameter =
 
 marshalPointParameter :: PointParameter -> GLenum
 marshalPointParameter x = case x of
-   PointSizeMin -> 0x8126
-   PointSizeMax -> 0x8127
-   PointFadeThresholdSize -> 0x8128
-   PointDistanceAttenuation -> 0x8129
+   PointSizeMin -> gl_POINT_SIZE_MIN
+   PointSizeMax -> gl_POINT_SIZE_MAX
+   PointFadeThresholdSize -> gl_POINT_FADE_THRESHOLD_SIZE
+   PointDistanceAttenuation -> gl_POINT_DISTANCE_ATTENUATION
 
 --------------------------------------------------------------------------------
 
 pointParameterf :: PointParameter -> GLfloat -> IO ()
-pointParameterf = glPointParameterfARB . marshalPointParameter
-
-EXTENSION_ENTRY("GL_ARB_point_parameters or OpenGL 1.4",glPointParameterfARB,GLenum -> GLfloat -> IO ())
+pointParameterf = glPointParameterf . marshalPointParameter
 
 pointParameterfv :: PointParameter -> Ptr GLfloat -> IO ()
-pointParameterfv = glPointParameterfvARB . marshalPointParameter
-
-EXTENSION_ENTRY("GL_ARB_point_parameters or OpenGL 1.4",glPointParameterfvARB,GLenum -> Ptr GLfloat -> IO ())
+pointParameterfv = glPointParameterfv . marshalPointParameter
