@@ -17,7 +17,7 @@ module Graphics.Rendering.OpenGL.GL.Texturing.Application (
    texture
 ) where
 
-import Data.StateVar
+import Graphics.Rendering.OpenGL.GL.StateVar
 import Graphics.Rendering.OpenGL.GL.Capability
 import Graphics.Rendering.OpenGL.GL.Texturing.Specification
 
