@@ -4,7 +4,7 @@
 -- Module      :  Graphics.Rendering.OpenGL.GL.Texturing.TextureUnit
 -- Copyright   :  (c) Sven Panne 2002-2009
 -- License     :  BSD-style (see the file libraries/OpenGL/LICENSE)
--- 
+--
 -- Maintainer  :  sven.panne@aedion.de
 -- Stability   :  stable
 -- Portability :  portable
@@ -17,7 +17,9 @@ module Graphics.Rendering.OpenGL.GL.Texturing.TextureUnit (
    TextureUnit(..), marshalTextureUnit, unmarshalTextureUnit
 ) where
 
-import Graphics.Rendering.OpenGL.GL.BasicTypes ( GLenum, GLuint )
+import Foreign.Ptr
+import Foreign.Storable
+import Graphics.Rendering.OpenGL.Raw.Core31
 
 --------------------------------------------------------------------------------
 
@@ -27,8 +29,19 @@ import Graphics.Rendering.OpenGL.GL.BasicTypes ( GLenum, GLuint )
 newtype TextureUnit = TextureUnit GLuint
    deriving ( Eq, Ord, Show )
 
+instance Storable TextureUnit where
+    sizeOf _                 = sizeOf    (undefined :: GLuint)
+    alignment _              = alignment (undefined :: GLuint)
+    peek pt                  = peek (castPtr pt) >>= return . TextureUnit
+    poke pt (TextureUnit tu) = poke (castPtr pt) tu
+    peekByteOff pt off       = peekByteOff pt off >>= return . TextureUnit
+    pokeByteOff pt off (TextureUnit tu)
+                             = pokeByteOff pt off tu
+
+
+
 marshalTextureUnit :: TextureUnit -> GLenum
-marshalTextureUnit (TextureUnit x) = 0x84c0 + fromIntegral x
+marshalTextureUnit (TextureUnit x) = gl_TEXTURE0 + fromIntegral x
 
 unmarshalTextureUnit :: GLenum -> TextureUnit
-unmarshalTextureUnit x = TextureUnit (fromIntegral (x - 0x84c0))
+unmarshalTextureUnit x = TextureUnit (fromIntegral (x - gl_TEXTURE0))
