@@ -16,10 +16,10 @@ module Graphics.Rendering.OpenGL.GLU.Initialization (
    gluVersion, gluExtensions
 ) where
 
-import Data.StateVar
 import Foreign.C.String
 import Foreign.Ptr
 import Graphics.Rendering.GLU.Raw
+import Graphics.Rendering.OpenGL.GL.StateVar
 import Graphics.Rendering.OpenGL.GL.QueryUtils
 import Graphics.Rendering.OpenGL.Raw.Core31
 
